@@ -7,12 +7,16 @@ import logging
 import os
 from pathlib import Path
 from tempfile import NamedTemporaryFile
+
+from pypyr.config import config
 from pypyr.errors import Error
+import pypyr.toml
 import pypyr.yaml
 
-# pypyr logger means the log level will be set correctly and output formatted.
 logger = logging.getLogger(__name__)
 
+# region Rewriters
+
 
 class FileRewriter(ABC):
     """FileRewriter reads input file, formats it and write to output file.
@@ -24,14 +28,22 @@ class FileRewriter(ABC):
     classes.
     """
 
-    def __init__(self, formatter):
+    def __init__(self, formatter, encoding_in=None, encoding_out=None):
         """Initialize formatter.
 
         Args:
             formatter: Callable object that will format the IN file payload to
                        create OUT file.
+            encoding_in: str | None. Encoding when reading input.
+            encoding_out: str | None. Encoding when reading output.
+
+        If you do not set encoding, will use the system default, which is utf-8
+        for everything except windows.
+
         """
         self.formatter = formatter
+        self.encoding_in = encoding_in
+        self.encoding_out = encoding_out
 
     @abstractmethod
     def in_to_out(self, in_path, out_path):
@@ -102,7 +114,7 @@ class FileRewriter(ABC):
                 # outpath could be a file, or a dir
                 pathlib_out = Path(out_path)
                 # yep, Path() strips trailing /, hence check original string
-                if isinstance(out_path, str) and out_path.endswith(os.sep):
+                if FileRewriter.is_str_dir(out_path):
                     # ensure dir - mimic posix mkdir -p
                     pathlib_out.mkdir(parents=True, exist_ok=True)
                     basedir_out = pathlib_out
@@ -119,7 +131,7 @@ class FileRewriter(ABC):
                     # at this point it must be a file (not dir) path
                     # make sure that the parent dir exists
                     basedir_out = pathlib_out.parent
-                    basedir_out.parent.mkdir(parents=True, exist_ok=True)
+                    basedir_out.mkdir(parents=True, exist_ok=True)
                     is_outfile_name_known = True
 
             # loop through all the in files and write them to the out dir
@@ -155,6 +167,23 @@ class FileRewriter(ABC):
         else:
             logger.info("%s found no files", in_path)
 
+    @staticmethod
+    def is_str_dir(s: str) -> bool:
+        """Return True if s ends with platform's dir separator(s)."""
+        if isinstance(s, str):
+            if config.is_windows:
+                # Not using os.sep here, because on windows pythonistas will
+                # use / as separator as easily as \.
+                # this is fine because win won't allow either / or \
+                # in filenames.
+                if s[-1] in {'/', '\\'}:
+                    return True
+            else:
+                # on posix only check for /.
+                if s.endswith(os.sep):
+                    return True
+        return False
+
 
 class ObjectRewriter(FileRewriter):
     """Load a single file into an object, run formatter on it and write out.
@@ -171,7 +200,8 @@ class ObjectRewriter(FileRewriter):
     serialization.
     """
 
-    def __init__(self, formatter, object_representer):
+    def __init__(self, formatter, object_representer,
+                 encoding_in=None, encoding_out=None):
         """Initialize formatter and object representer.
 
         Args:
@@ -179,11 +209,14 @@ class ObjectRewriter(FileRewriter):
                        from in file. Formatter signature:
                        iterable = formatter(iterable)
             object_representer: An ObjectRepresenter instance.
+            encoding_in: str | None. Optional. Encoding when reading input.
+            encoding_out: str | None. Optional. Encoding when reading output.
 
+        If you do not set encoding, will use the system default, which is utf-8
+        for everything except windows.
         """
-        super().__init__(formatter)
+        super().__init__(formatter, encoding_in, encoding_out)
         self.object_representer = object_representer
-        logger.debug('obj loader set')
 
     def in_to_out(self, in_path, out_path=None):
         """Load file into object, formats, writes object to out.
@@ -211,21 +244,27 @@ class ObjectRewriter(FileRewriter):
             out_path = None
 
         logger.debug("opening source file: %s", in_path)
-        with open(in_path) as infile:
+
+        read_mode = self.object_representer.read_mode
+
+        with open(in_path, read_mode, encoding=self.encoding_in) as infile:
             obj = self.object_representer.load(infile)
 
+        write_mode = self.object_representer.write_mode
         if out_path:
             logger.debug(
                 f"opening destination file for writing: {out_path}")
-            ensure_dir(out_path)
-            with open(out_path, 'w') as outfile:
+            # out directory must exist
+            with open(out_path, write_mode,
+                      encoding=self.encoding_out) as outfile:
                 self.object_representer.dump(outfile, self.formatter(obj))
             return
         else:
             logger.debug("opening temp file for writing...")
-            with NamedTemporaryFile(mode='w+t',
+            with NamedTemporaryFile(mode=write_mode,
                                     dir=os.path.dirname(in_path),
-                                    delete=False) as outfile:
+                                    delete=False,
+                                    encoding=self.encoding_out) as outfile:
                 self.object_representer.dump(outfile, self.formatter(obj))
 
             logger.debug("moving temp file to: %s", in_path)
@@ -277,19 +316,21 @@ class StreamRewriter(FileRewriter):
             is_in_place_edit = True
 
         logger.debug("opening source file: %s", in_path)
-        with open(in_path) as infile:
+        with open(in_path, encoding=self.encoding_in) as infile:
             if out_path:
                 logger.debug(
                     "opening destination file for writing: %s", out_path)
-                ensure_dir(out_path)
-                with open(out_path, 'w') as outfile:
+                # at this point out dir must exist
+                with open(out_path, 'w',
+                          encoding=self.encoding_out) as outfile:
                     outfile.writelines(self.formatter(infile))
                 return
             else:
                 logger.debug("opening temp file for writing...")
                 with NamedTemporaryFile(mode='w+t',
                                         dir=os.path.dirname(in_path),
-                                        delete=False) as outfile:
+                                        delete=False,
+                                        encoding=self.encoding_out) as outfile:
                     outfile.writelines(self.formatter(infile))
 
                 is_in_place_edit = True
@@ -302,6 +343,10 @@ class StreamRewriter(FileRewriter):
             logger.debug("moving temp file to: %s", in_path)
             move_temp_file(outfile.name, infile.name)
 
+# endregion Rewriters
+
+# region Representers
+
 
 class ObjectRepresenter(ABC):
     """Abstract base class to handle object serialization and deserialization.
@@ -310,8 +355,25 @@ class ObjectRepresenter(ABC):
     serialize and deserialize a payload.
 
     This tends to be useful for the ObjectRewriter.
+
+    Attributes:
+        read_mode: open underlying file in text 'rt' or binary 'rb' mode.
+        write_mode: open underlying file in text 'wt' or binary 'wb' mode.
     """
 
+    def __init__(self, is_binary=False):
+        """Initialize object representer in binary or text mode.
+
+        Args:
+            is_binary (bool): Set true if representer expects bytes, not str.
+        """
+        if is_binary:
+            self.read_mode = 'rb'
+            self.write_mode = 'wb'
+        else:
+            self.read_mode = 'rt'
+            self.write_mode = 'wt'
+
     @abstractmethod
     def load(self, file):
         """Instantiate object from input file."""
@@ -333,13 +395,12 @@ class JsonRepresenter(ObjectRepresenter):
             file: Open file-like object.
 
         Returns:
-            None.
-
+            Json represented as a python object.
         """
         return json.load(file)
 
     def dump(self, file, payload):
-        """Dump json oject to open file output.
+        """Dump json object to open file output.
 
         Writes json with 2 spaces indentation.
 
@@ -351,7 +412,39 @@ class JsonRepresenter(ObjectRepresenter):
             None.
 
         """
-        json.dump(payload, file, indent=2, ensure_ascii=False)
+        json.dump(payload, file, indent=config.json_indent,
+                  ensure_ascii=config.json_ascii)
+
+
+class TomlRepresenter(ObjectRepresenter):
+    """Load and dump a toml payload. Useful for ObjectRewriter."""
+
+    def __init__(self):
+        """Initialize in binary mode."""
+        super().__init__(True)
+
+    def load(self, file):
+        """Load Toml object from open file input.
+
+        Args:
+            file: Open file-like object in binary mode.
+
+        Returns:
+            Dict.
+        """
+        return pypyr.toml.load(file)
+
+    def dump(self, file, payload):
+        """Dump toml object to open file output.
+
+        Args:
+            file: Open file-like object. Must be open for binary writing.
+            payload: The Toml object to write to file.
+
+        Returns:
+            None.
+        """
+        pypyr.toml.dump(payload, file)
 
 
 class YamlRepresenter(ObjectRepresenter):
@@ -359,6 +452,7 @@ class YamlRepresenter(ObjectRepresenter):
 
     def __init__(self):
         """Instantiate the yaml representer."""
+        super().__init__()
         self.yaml_parser = pypyr.yaml.get_yaml_parser_roundtrip()
 
     def load(self, file):
@@ -370,8 +464,7 @@ class YamlRepresenter(ObjectRepresenter):
             file: Open file-like object.
 
         Returns:
-            None.
-
+            Yaml represented as python object.
         """
         return self.yaml_parser.load(file)
 
@@ -390,6 +483,8 @@ class YamlRepresenter(ObjectRepresenter):
         """
         self.yaml_parser.dump(payload, file)
 
+# endregion Representers
+
 
 def ensure_dir(path):
     """Create all parent directories of path if they don't exist.
